Volcano Plot
============

Plots significance versus fold-change for gene expression rates.


**Inputs**
- Data: Input data set.

**Outputs**
- Selected Data: Data subset.



[**Volcano plot**](https://en.wikipedia.org/wiki/Volcano_plot_(statistics)) is a graphical method for
visualizing changes in replicate data. The widget plots a binary logarithm of fold-change on the x-axis versus
[statistical significance](https://en.wikipedia.org/wiki/Statistical_significance)
(negative base 10 logarithm of p-value) on the y-axis.

**Volcano Plot** is useful for a quick visual identification of statistically significant
data (genes). Genes that are highly dysregulated are
farther to the left and right, while highly significant fold changes appear higher on the plot.
A combination of the two are those genes that are statistically significant.

Example
-------

TODO!